<?php
/*
Better Backgrounds
Wordpress Plugin

Copyright 2011 by Dave Coleman (email: dave@davetcoleman.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/

//Admin Backend Functions -----------------------------------------------------------------------------
		
if(!load_plugin_textdomain('bbg','/wp-content/languages/'))
	load_plugin_textdomain('bbg','/wp-content/plugins/better-backgrounds/languages/');

// Hook for adding admin menus
add_action('admin_menu', 'bbg_add_pages');

// Action function for above hook
function bbg_add_pages() {

	// Add a new submenu under Appearance:
	$page = add_submenu_page('themes.php', 'Better Backgrounds', 'Better Backgrounds', 8, 'bbg_options', 'bbg_options_page');
	add_action("load-$page", 'bbg_admin_load');
}

//Added this to get the color wheel working:
//Set up the enqueue for the CSS & JavaScript files.
function bbg_admin_load() {
	
	//add_contextual_help( $this->page, '<p>' . __( 'You can customize '));
	wp_enqueue_script('custom-background');
	wp_enqueue_style('farbtastic');
}
	
//Show the Admin Settings Page for this plugin
function bbg_options_page() {
	//not needed? global $_POST;
	
	
	//For use with instruction images. The first method doesnt work on my local server because I have a virtual joined plugin directory
	//$plugin_path = WP_PLUGIN_URL.'/'.str_replace(basename( __FILE__),"",plugin_basename(__FILE__));
	$plugin_path = WP_PLUGIN_URL.'/better-backgrounds/';
	
	$updateMessage = false;	//when true show updated message
	$wpBGMessage = false;	//warn that wordpress already has their background set
	$errored = false;	//when true show error message
	
	//Check user privileges
	if ( !bbg_is_authorized())
		_e('You do not have sufficient privileges.', 'bbg');
		
	//Process form submission
	if (isset($_POST['bbg_path'])) {
		
		update_option('bbg_path',$_POST['bbg_path']);
		
		//Backgroud Layout
		if (isset($_POST['bbg_layout'])) {
			update_option('bbg_layout',$_POST['bbg_layout']);
		}
		
		//Random Image Change Interval
		if (isset($_POST['bbg_interval'])) {
			update_option('bbg_interval',$_POST['bbg_interval']);
		}
		
		//Continously on timer interval
		if (isset($_POST['bbg_interval_timer'])) {
			update_option('bbg_interval_timer',$_POST['bbg_interval_timer']);
		}
		
		//Checkboxes need to have an else statement
		if (isset($_POST['bbg_fade'])) {
			update_option('bbg_fade',1);
		}else{
			update_option('bbg_fade',0);
		}
		
		//Hyperlink
		if (isset($_POST['bbg_link'])) {
			update_option('bbg_link',$_POST['bbg_link']);
		}
		
		//Height value
		if (isset($_POST['bbg_height'])) {
			update_option('bbg_height',$_POST['bbg_height']);
		}
		
		//Color value
		if ( isset($_POST['background-color']) ) {
			$color = preg_replace('/[^0-9a-fA-F]/', '', $_POST['background-color']);
			if ( strlen($color) == 6 || strlen($color) == 3 )
				set_theme_mod('background_color', $color);
			else
				set_theme_mod('background_color', '');
		}
		
		
		$updateMessage = true;
	}
	
	//Check if Wordpress Background image is being used
		$background = get_background_image();
        //$color = get_background_color();
        if ($background)
            $wpBGMessage = true;
	?>
	
	
	<div class="wrap" style="max-width:1100px;">
			
		<div id="icon-themes" class="icon32"><br></div>
		<div style="float:left;">
			<h2><?php _e('Better Custom Backgrounds', 'bbg'); ?></h2>
			<i><?php _e('Keep your site looking fresh!', 'bbg'); ?></i> &nbsp;&nbsp;
			<a href="http://davetcoleman.com/blog/random-background-image-per-session" target="_blank"><?php _e('Help & Support', 'bbg'); ?></a>
		</div>
		<div style="clear:left;">&nbsp;</div>
		
		<?php if($updateMessage): ?>
			<div id="message" class="updated below-h2">
				<p>
					<?php _e('Background updated.', 'bbg'); ?> 
					<a href="<?php echo get_settings('home'); ?>"><?php _e('Visit your site', 'bbg'); ?></a> 
					<?php _e('to see how it looks.', 'bbg'); ?>
				</p>
			</div>
		<?php endif; ?>	
		
		<form action="" method="post">
		  <input type="hidden" name="redirect" value="true" />
			<h3><?php _e('Background Images', 'bbg'); ?></h3>
			
			<? if (! is_plugin_active('nextgen-gallery/nggallery.php')): ?>
				<p><?php _e('You are in manual upload mode and may need access to FTP to add background images. For easier use we recommend you install the <a href="http://wordpress.org/extend/plugins/nextgen-gallery/">NextGen Gallery</a> Wordpress plugin and return to this page.', 'bbg'); ?></p>
			<? endif; ?>
			
			<ol>
				<li>
					<b><?php _e('Find/create background images', 'bbg'); ?></b>
					<br />
					<ul style="list-style:circle;margin-left:20px;">
						<li><?php _e('Required formats: .png, .gif, or .jpg', 'bbg'); ?></li>
						<li><?php _e('Based on today\'s browser display statistics, a good recommended size is 1280px x 1024px.', 'bbg'); ?></li>
					</ul>
				</li>
				
				
				<?php 
				// If NextGen Galley plugin is installed, force user to use that because it makes this interface way easier. possible todo: allow NGG users to override this if they want. 
				if (is_plugin_active('nextgen-gallery/nggallery.php')): ?>
				
					<li>
						<b><?php _e('Upload images to a new ','bbg'); ?>
							<a href="admin.php?page=nggallery-add-gallery"><?php _e('Nextgen Gallery'); ?></a>
						</b>
					</li>
					<li>
						<b><?php _e('Choose your NextGen gallery from the list below', 'bbg'); ?></b>
						<br/>
						<input type="hidden" name="bbg_path" id="bbg_path" size="65" value="<?php echo get_option('bbg_path'); ?>" /> 
					 
						<?php
						global $wpdb;
						$galleries = $wpdb->get_results( "SELECT gid, name, path FROM wp_ngg_gallery" );
						?>
						<select id="ngg-galleries-select" style="width:400px;">
							<option value=""><i><?php _e('Choose your NextGen Gallery', 'bbg'); ?></i></option>
																				  
							<?php foreach ($galleries as $gallery) { ?>
								<option value="<?php echo $gallery->path; ?>" <?php echo (get_option('bbg_path')==$gallery->path?'selected="selected"':''); ?> ><?php echo $gallery->gid . ' - '. $gallery->name; ?></option>
							<?php } ?>
							
						</select>
							  
						<script>                                        
							jQuery("#ngg-galleries-select").change(function () {
								var ngGallery = jQuery(this).val();
								jQuery("#bbg_path").val(ngGallery);
							});
						</script>
					</li>
					
				<?php else: ?>
			
					<li>
						<b><?php _e('Create BG images folder','bbg'); ?></b><br /><?php _e('within your Wordpress installation. It can be in your theme folder or, recommended, uploads folder: (wp-content/uploads/bg-images/)', 'bbg'); ?>
					</li>
					<li>
						<b><?php _e('Enter the server sub-folder path', 'bbg'); ?></b> <?php _e('to where you put the BG images:', 'bbg'); ?>
						<br/>
						<?php echo str_replace('\\','/', ABSPATH);  ?>
						<input type="text" name="bbg_path" id="bbg_path" size="65" value="<?php echo get_option('bbg_path'); ?>" /> 
						<i><?php _e('(e.g. wp-content/uploads/bg-images/)', 'bbg'); ?></i>
						
						<br />&nbsp;
					</li>
					
				<?php endif; ?>
			</ol>
			
			
			
			<style type="text/css">
				.bbg_layout_columns {
				
					
					vertical-align: middle;
				}
				.bbg_layout_columns label{
					font-weight:bold;
					verticle-align:top;
				}
			
			</style>
			
			
			
			
			<h3><?php _e('Background Layout', 'bbg'); ?></h3>
			<table cellspacing=10>
				<tr>
					<td><img src="<?php echo $plugin_path; ?>/screenshot-1.jpg"></td>
					<td><img src="<?php echo $plugin_path; ?>/screenshot-2.jpg"></td>
					<td><img src="<?php echo $plugin_path; ?>/screenshot-3.jpg"></td>
				</tr>
				<tr valign="top" >
					<?php $bbg_layout = get_option('bbg_layout','fixed') ?>
					<td>
						<div class="bbg_layout_columns">
							<input type="radio" id="bbg_layout1" name="bbg_layout" value="fixed" <?php echo $bbg_layout=='fixed'?'CHECKED':'' ?> > 
							<label for="bbg_layout"><?php _e('Full Page Width & Height, Fixed', 'bbg'); ?></label>
							<br />
							<i><?php _e('Recommended', 'bbg'); ?></i>
							<br />
							<?php _e('Background remains the same as you scroll down the page. Scaled and centered to fill entire browser window. Easiest background to implement well.', 'bbg'); ?>
						</div>
					</td>
					<td>
						<div class="bbg_layout_columns">
							<input type="radio" id="bbg_layout2" name="bbg_layout" value="scrolling" <?php echo $bbg_layout=='scrolling'?'CHECKED':'' ?>> 
							<label for="bbg_layout"><?php _e('Full Page Width & Custom Height, Scrolling', 'bbg'); ?></label>
							<br />
							<?php _e('Background aligned to top of screen and moves out of view as you scroll down the page. Scaled to full browser width and custom height (default: full browser height). A graphical fade on the bottom of the background image or secondary background pattern is recommended.', 'bbg'); ?>
						</div>
					</td>
					<td>
						<div class="bbg_layout_columns">
							<input type="radio" id="bbg_layout3" name="bbg_layout" value="basic" <?php echo $bbg_layout=='basic'?'CHECKED':'' ?>> 
							<label for="bbg_layout"><?php _e('Basic Unstretched Centered Image, Scrolling', 'bbg'); ?></label>
							<br />
							<?php _e('Classic background - more standards compliant using the body\'s background tag. Does not scale the background to fit the page\'s width, so make sure background is high enough resolution for widescreen monitors. Does not support fading in.', 'bbg'); ?>
						</div>
					</td>
				</tr>
			</table>
			
			<script>
				//Only show options that are applicable to the current selected layout
				jQuery("[name]='bbg_layout'").change(function () {
					var layout = jQuery(this).val();
					switch(layout){
						case 'fixed':
							jQuery('#li_bbg_height').hide();
							jQuery('#wordpress_bg_message').hide();
							jQuery('#li_bbg_fade').show();
							break;
						case 'scrolling':
							jQuery('#li_bbg_height').show();
							jQuery('#wordpress_bg_message').hide();
							jQuery('#li_bbg_fade').show();
							break;
						case 'basic':
							jQuery('#li_bbg_height').hide();
							jQuery('#wordpress_bg_message').show();
							jQuery('#li_bbg_fade').hide();
							break;
					}
				});			
			</script>
			
			
			<?php if($wpBGMessage): ?>
				<div id="wordpress_bg_message" class="updated below-h2" <?php if($bbg_layout != 'basic') echo "style='display:none;'" ?>>
					<p>
						<?php _e('The default <a href="themes.php?page=custom-background">Wordpress Background</a> functionality is still enabled. This will interfere with this layout mode and cause graphical problems. Please disable Wordpress\' default background by clicking on Appearance->Background->Remove Background Image.', 'bbg'); ?> 
					</p>
				</div>
			<?php endif; ?>
			
			<h3><?php _e('Random Image Change Interval', 'bbg'); ?></h3>
			<ul style="margin-left:25px;">
				<?php $bbg_interval = get_option('bbg_interval','page') ?>
				<li>
					<div style="vertical-align: middle;margin-left:-20px;">
						<input type="radio" id="bbg_interval1" name="bbg_interval" value="session" <?php echo $bbg_interval=='session'?'CHECKED':'' ?>> 
						<label><b><?php _e('Once A Visitor Session', 'bbg'); ?></b></label>
					</div>
					<?php _e('The same random image will be used on every page of the site, until they visit on a different session (uses cookies).', 'bbg'); ?>
				</li>
				<li>
					<div style="vertical-align: middle;margin-left:-20px;">
						<input type="radio" id="bbg_interval2" name="bbg_interval" value="page" <?php echo $bbg_interval=='page'?'CHECKED':'' ?>> 
						<label><b><?php _e('Every Page Refresh', 'bbg'); ?></b></label>
					</div>
					<?php _e('Every time a visitor changes pages a new random image is chosen.', 'bbg'); ?>
				</li>
				<li>
					<div style="vertical-align: middle;margin-left:-20px;">
						<input type="radio" id="bbg_interval3" name="bbg_interval" value="continuous" <?php echo $bbg_interval=='continuous'?'CHECKED':'' ?>> 
						<label><b><?php _e('Continuously On Timer Interval (Slideshow)', 'bbg'); ?></b></label>
					</div>
					<?php _e('Background images will loop through like a slideshow.', 'bbg'); ?>
					<br />
					<?php _e('Change Background Every', 'bbg'); ?> <input type="text" size=2 name="bbg_interval_timer" value="<?php echo get_option('bbg_interval_timer', 10); ?>"> <?php _e('seconds', 'bbg'); ?>
				</li>
			</ul>
			
			<h3><?php _e('Display Options', 'bbg'); ?></h3>
			<ol>
				<li id="li_bbg_fade" <?php if($bbg_layout != 'basic') echo "style='display:none;'" ?>>
					<input type="checkbox" name="bbg_fade" value="on" <?php echo (get_option('bbg_fade',0)?'checked="yes"':'') ?> /> 
					<b><?php _e('Fade In Background Dynamically', 'bbg'); ?></b>
					<i>(<?php _e('default: disabled', 'bbg'); ?>)</i>
					<br/>
					<?php _e('Uses the jQuery fade effect to show your background.', 'bbg'); ?>
				</li>
				<!-- Couldn't get this to work because the page's wrapper is ontop of the background image - thus it has the click event
				<li>
					<b><?php _e('Add Hyperlink URL To Background', 'bbg'); ?></b>
					<i>(<?php _e('optional', 'bbg'); ?>)</i>
					<br/>
					<?php _e('Makes the entire background of page clickable to open url in new window. Leave blank to disable.', 'bbg'); ?>
					<br />
					<input type="text" name="bbg_link" size="60" value="<?php echo get_option('bbg_link'); ?>" /> <i>(e.g. "http://google.com/")</i>
				</li-->
				<li>
					<b><?php _e('Background Color', 'bbg'); ?></b>
					<br/>
					<fieldset>
						<input type="text" name="background-color" id="background-color" value="#<?php echo get_background_color(); ?>" /> 
						<a class="hide-if-no-js" href="#" id="pickcolor"><?php _e('Select a Color', 'bbg'); ?></a> 
						<div id="colorPickerDiv" style="z-index: 100; background:#eee; border:1px solid #ccc; position:absolute; display:none;"></div> 
					</fieldset>
				</li>
				
			
				<li id="li_bbg_height" <?php if($bbg_layout != 'scrolling') echo "style='display:none;'" ?>>
					<b><?php _e('Set the height of background.', 'bbg'); ?></b>
					<i>(<?php _e('optional', 'bbg'); ?>)</i><br/>
					<?php _e('Full page width, scrolling layout only. There is no height by default. If you want backgrounds to fit width and height of your page, you can set the height to 100%. Otherwise you can set the height in pixels.', 'bbg'); ?></i>
					<br />
					<input type="text" name="bbg_height" size=10 value="<?php echo get_option('bbg_height'); ?>" /> <i>(e.g. "800px")</i>
				</li>
			</ol>
			<br />
			
			<p><input type="submit" value="<?php _e('Save Settings', 'bbg'); ?>" class="button-primary"/></p>
			<br />
			
			<h3><?php _e('Advanced Tips', 'bbg'); ?></h3>
			<ol>
				<li>
					<b><?php _e('Disable Wordpress\'s default Background','bbg'); ?></b>
					<br />
					<?php _e('Unless you want a image pattern below your main background image, we recommend you disable the default <a href="themes.php?page=custom-background">Wordpress Background</a>. Simply click on Appearance->Background->Remove Background Image. Another option would be to edit your theme\'s function.php file and remove the function add_custom_background(), if applicable.', 'bbg'); ?>
				</li>
				<li>
					<b><?php _e('Fix your CSS style sheet', 'bbg'); ?></b><br/>
					<?php _e('If the background is not appearing correctly  you might need to edit your theme\'s style sheet. Go to the "Appearance" menu on the left and click the "Editor" sub-menu item. On the following page you should be editing "style.css". Find your page\'s main div wrapper - this is the first html element after the &#60;body&#62; tag. Within the style for this element add the following two lines:', 'bbg'); ?><br />
					&nbsp;&nbsp;<i>z-index:2;<br />
					&nbsp;&nbsp;position:relative;</i><br />
					<?php _e('Save the style sheet changes and hopefully you are ready to go!', 'bbg'); ?>
				</li>
			</ol>
			<br /><br />
		</form>
	</div>
	<?php
}

/**
* Add Settings link to Admin plugins page - code from GD Star Ratings
*/
function bbg_add_settings_link($links, $file) {
	
	if ($file == 'better-backgrounds/better-backgrounds.php'){
		$settings_link = '<a href="themes.php?page=bbg_options">'.__("Settings", "bbg").'</a>';
		array_unshift($links, $settings_link);
	}
	return $links;
}

add_filter('plugin_action_links', 'bbg_add_settings_link', 10, 2 );




//Helper Functions -----------------------------------------------------------------------------

//Check to see if user has sufficient privileges to edit the plugin settings in the admin
function bbg_is_authorized() 
{
	global $user_level;
	if (function_exists("current_user_can")) {
		return current_user_can('activate_plugins');
	} else {
		return $user_level > 5;
	}
}