<?php
/*
Plugin Name: Better Backgrounds
Plugin URI:  http://davetcoleman.com/blog/bbg
Version:     2.0.0
Description: Random background image every visitor session, page refresh, or timed slideshow interval. Choose between fixed full screen background or scrolling background.
Author:      Dave Coleman
Author URI:  http://davetcoleman.com/

Copyright 2011 by Dave Coleman (email: dave@davetcoleman.com)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

*/
	
//Only include the admin config code if in Wordpress Admin Backend	
if(is_admin()){
	include('bbg_admin.php');
}


//Frontend Display Functions -----------------------------------------------------------------------------

//Load plugin options
	$bbg_layout = get_option('bbg_layout','fixed');
	$bbg_interval = get_option('bbg_interval','page');
	$bbg_interval_timer = get_option('bbg_interval_timer','10');
	$bbg_link = get_option('bbg_link','');
	$bbg_fade = get_option('bbg_fade', 0);
	$bbg_height = get_option('bbg_height','100%');
	
//Only require jQuery be loaded if this option has been checked
	if($bbg_fade || $bbg_interval == 'continuous')
		wp_enqueue_script("jquery");
	
//Start the session now before headers are sent out
	if($bbg_interval == 'session')
		session_start();
	
//Add the background html code filter hook
	add_filter( 'wp_head', bbg_header ); 
	add_filter( 'wp_footer', bbg_footer ); 

//Set bbg_image as global so it can be passed to the footer
global $bbg_image;

function bbg_header()
{
	global $bbg_interval, $bbg_layout, $bbg_interval_timer, $bbg_height, $bbg_image;

					
	//Get the URL to the background image
	if($bbg_interval == 'session')
	{
		//Check if there is already a BG saved in session
		session_start();
		
		if(isset($_SESSION['bbg_background']))	//already have session bg 
		{
			$bbg_image = $_SESSION['bbg_background'];	//get from cookie
		}
		else
		{
			$bbg_image = generateRandomImage();	//pull from folder a random bg
			$_SESSION['bbg_background'] = $bbg_image;	//save image to session
		}
	}
	else
	{
		$bbg_image = generateRandomImage();	//pull from folder a rand bg
	}	
		
	//Create and embed the style sheet ----------------------------------------------
	
	?>
	<style type="text/css">
	<?php
	
	//Decided what to do based on layout
	switch($bbg_layout){
		//-------------------------------------------------------------------------------------------------------
		case 'fixed':			
			?>
				/*  Better Backgrounds Plugin: styles automatically inserted based on plugin settings 
					Based on: http://css-tricks.com/perfect-full-page-background-image/
				*/
				img.bg-rand {
					/* Set rules to fill background */
					min-height: 100%;
					min-width: 1024px;

					/* Set up proportionate scaling */
					width: 100%;
					height: auto;

					/* Set up positioning */
					position: fixed;
					top: 0;
					left: 0;
					z-index:-1;
				}

				@media screen and (max-width: 1024px) { /* Specific to this particular image */
					img.bg-rand {
						left: 50%;
						margin-left: -512px;   /* 50% */
					}
				}	
			<?php	
			
			break;
		//-------------------------------------------------------------------------------------------------------
		case 'scrolling':
			//Create the css height property if applicable
			if(!empty($bg_height))
				$bg_height = 'height:'. $bg_height .';';	
				
			?>
				/* Random background per session plugin: styles automatically inserted based on plugin settings */
				img.bg-rand {
					position:absolute;
					top:0;
					left:0;
					z-index:-1;
					width:100%;
					<?php echo $bg_height; ?>
				}
			<?php	
			break;
		//-------------------------------------------------------------------------------------------------------
		case 'basic':
		
			$color = get_background_color();
			$style = $color ? "background-color: #$color;" : '';
			$image = " background-image: url('$bbg_image');";
			$repeat = " background-repeat: no-repeat;";
			$position = " background-position: top center;";
			$attachment = " background-attachment: scroll;";
			$style .= $image . $repeat . $position . $attachment;
			
			?>
			body { <?php echo trim( $style ); ?> }
			<?php
			
		break;
	}
	?>
	</style>
	<?php
	
}

//Now output the img tag and any javascript
function bbg_footer()
{
	global $bbg_link, $bbg_fade, $bbg_image, $bbg_interval, $bbg_interval_timer, $bbg_layout;
	
	//Outuput the actual image
	?>
	<img id="bg-rand" class="bg-rand" src="<?php echo $bbg_image; ?>"  />
	<img id="bg-preloader" style="display:none;"/>
	
	<script type="text/javascript">
		//Automatically Generated Scripts from the Better Backgrounds Wordpress Plugin 
		<?php
		
		//Check if jQuery fade effect is to be used
		if($bbg_fade && $bbg_layout != 'basic'): 
			?>
				jQuery("#bg-rand").hide().fadeIn(1500);
			<?php 
		endif;
		
		//Show the hyperlink
		/*if(!empty($bbg_link)): 
			
				jQuery("#bg-rand").click(function(){
					document.location = '<?php echo $bbg_link; ?>';
				});
			
		endif;*/
		
		//Timer Interval Slideshow
		if($bbg_interval == 'continuous'):
		
			bbg_outputJSList();
			?>
				//Set the timer
				setInterval("bbg_changeBackground()", <?php echo $bbg_interval_timer * 1000; ?>);
				
				//Preload next background on page load
				jQuery('#bg-preloader').attr('src',bbg_images[bbg_image_array_pointer]);
				
				//Change the background
				function bbg_changeBackground(){
					
					
					//jQuery("#bg-rand").fadeOut(200, 'linear', function(){
						//jQuery("#bg-rand").attr('src',bbg_images[bbg_image_array_pointer]).fadeIn(400,'linear');
					//});
					
					<?php if($bbg_layout == 'basic'): ?>
					
						jQuery("body").css('background-image','url('+bbg_images[bbg_image_array_pointer]+')');
						
					<?php else: ?>
					
						jQuery("#bg-rand").hide().attr('src',bbg_images[bbg_image_array_pointer]).fadeIn(400,'linear');
						
					<?php endif; ?>
					
					//Get next image index
					bbg_image_array_pointer ++;
					
					if(bbg_image_array_pointer > bbg_images.length)
						bbg_image_array_pointer = 0;
						
					//Pre-load next background
					jQuery('#bg-preloader').attr('src',bbg_images[bbg_image_array_pointer]);
				}
				
			<?php 
		endif;
		
		?>	
	</script>
	
	<?php
}

		
$bbg_image_array_pointer = 0;
$bbg_image_array = null;

//This is where the random image is chosen
function generateRandomImage()
{
	global $bbg_image_array_pointer, $bbg_image_array;
	
	$imageSubPath = get_option('bbg_path','wp-content/uploads/bg-images/');
    $physicalPath = ABSPATH . $imageSubPath;
	$virtualPath = get_bloginfo('wpurl') . "/" . $imageSubPath;
	
    $image_types = array('jpg','png','gif'); // Array of valid image types
    $image_directory = @opendir($physicalPath);

	//Check if directory does not exist
	if($image_directory === false){
		return false;
	}
	
	//Loop through every file in directory
    while($image_file = readdir($image_directory))
    {		
		//Check if the file type is one of the 3 acceptable
		if(in_array(strtolower(substr($image_file,-3)),$image_types)) {
		
			//Add file to image array
			$bbg_image_array[] = $virtualPath.'/'.$image_file;
			
		}
    }
	
	//Choose a random index from the array
	$image_array_pointer = rand(1,count($bbg_image_array))-1;
	
	//Get the index's image
    $chosen_image = $bbg_image_array[$image_array_pointer];
	
	//Progress to the next index
	$image_array_pointer ++;
	if($image_array_pointer > count($bbg_image_array))
		$image_array_pointer = 0;
	
	return $chosen_image;
}

//This creates a list of backgrounds for the javascript to loop through
function bbg_outputJSList(){
	global $bbg_image_array_pointer, $bbg_image_array;
		
	?>
		var bbg_image_array_pointer = <?php echo $bbg_image_array_pointer; ?>;
		var bbg_images = new Array(<?php echo count($bbg_image_array); ?>);
		
	<?php foreach ($bbg_image_array as $key => $value): ?>
		bbg_images[<?php echo $key; ?>] = "<?php echo $value; ?>";
	<?php endforeach;
	
	
	
}
